@@ -111,12 +111,6 @@ def parse_args(args):
 		action="store_true",
 		dest="no_target_directory"
 	)
-	parser.add_argument(
-		"--context",
-		"-Z",
-		action="store",
-		dest="context"
-	)
 	parser.add_argument(
 		"--verbose",
 		"-v",
@@ -143,11 +137,21 @@ def parse_args(args):
 	# for known options in order for argparse to correctly
 	# separate option arguments from file arguments in all
 	# cases (it also allows for optparse compatibility).
-	parsed_args = parser.parse_known_args()
+	(opts, args) = parser.parse_known_args(args)
 
-	opts  = parsed_args[0]
-	files = parsed_args[1]
-	files = [f for f in files if f != "--"]	# filter out "--"
+	files = []
+	i = 0
+	while i < len(args):
+		if args[i] == "--":
+			i += 1
+			break
+		if not args[i].startswith("-"):
+			files.append(args[i])
+		i += 1
+
+	while i < len(args):
+		files.append(args[i])
+		i += 1
 
 	return (opts, files)
 
@@ -228,16 +232,15 @@ def main(args):
 	cmdline = [install_binary]
 	cmdline += args
 
-	if sys.hexversion >= 0x3000000:
-		# We can't trust that the filesystem encoding (locale dependent)
-		# correctly matches the arguments, so use surrogateescape to
-		# pass through the original argv bytes for Python 3.
-		fs_encoding = sys.getfilesystemencoding()
-		cmdline = [x.encode(fs_encoding, 'surrogateescape') for x in cmdline]
-		files = [x.encode(fs_encoding, 'surrogateescape') for x in files]
-		if opts.target_directory is not None:
-			opts.target_directory = \
-				opts.target_directory.encode(fs_encoding, 'surrogateescape')
+	# We can't trust that the filesystem encoding (locale dependent)
+	# correctly matches the arguments, so use surrogateescape to
+	# pass through the original argv bytes for Python 3.
+	fs_encoding = sys.getfilesystemencoding()
+	cmdline = [x.encode(fs_encoding, 'surrogateescape') for x in cmdline]
+	files = [x.encode(fs_encoding, 'surrogateescape') for x in files]
+	if opts.target_directory is not None:
+		opts.target_directory = \
+			opts.target_directory.encode(fs_encoding, 'surrogateescape')
 
 	returncode = subprocess.call(cmdline)
 	if returncode == os.EX_OK:
